@@ -52,17 +52,24 @@ class Client:
         await utils.timed_send_key(self.window_handle, key, seconds)
 
     async def click(
-        self, x: int, y: int, *, right_click: bool = False, sleep_duration: float = 0.1
+        self,
+        x: int,
+        y: int,
+        *,
+        right_click: bool = False,
+        sleep_duration: float = 0.0,
+        use_post: bool = False,
     ):
         """
         Send a click to a certain x and y
-        x and y positions are relitive to the top left corner of the screen
+        x and y positions are relative to the top left corner of the screen
 
         Args:
             x: x to click at
             y: y to click at
             right_click: If the click should be a right click
-            sleep_duration: how long to sleep between messages
+            sleep_duration: How long to sleep between messages
+            use_post: If PostMessage should be used instead of SendMessage
         """
         # prevent multiple clicks from happening at the same time
         if right_click:
@@ -70,18 +77,22 @@ class Client:
         else:
             button_down_message = 0x201
 
+        if use_post:
+            send_method = user32.PostMessageW
+        else:
+            send_method = user32.SendMessageW
+
         if self.click_lock is None:
             self.click_lock = asyncio.Lock()
 
         async with self.click_lock:
             await self.set_mouse_position(x, y)
-            # position doesn't matter here; sending mouse move
-            user32.SendMessageW(self.window_handle, 0x200, 0, 0)
-            await asyncio.sleep(sleep_duration)
-            # mouse left button down
-            user32.SendMessageW(self.window_handle, button_down_message, 1, 0)
-            await asyncio.sleep(sleep_duration)
-            user32.SendMessageW(self.window_handle, button_down_message + 1, 0, 0)
+            # mouse button down
+            send_method(self.window_handle, button_down_message, 1, 0)
+            if sleep_duration > 0:
+                await asyncio.sleep(sleep_duration)
+            # mouse button up
+            send_method(self.window_handle, button_down_message + 1, 0, 0)
 
     def login(self, username: str, password: str):
         """
@@ -157,23 +168,34 @@ class Client:
         target_xyz = utils.XYZ(x, y, current_xyz.z)
         distance = current_xyz - target_xyz
         move_seconds = distance / (WIZARD_SPEED * speed_multiplier)
-        yaw = utils.calculate_perfect_yaw(current_xyz, target_xyz)
+        yaw = current_xyz.yaw(target_xyz)
 
         await self.set_yaw(yaw)
         await utils.timed_send_key(self.window_handle, Keycode.W, move_seconds)
 
     async def set_mouse_position(
-        self, x: int, y: int, *, convert_from_client: bool = True
+        self,
+        x: int,
+        y: int,
+        *,
+        convert_from_client: bool = True,
+        use_post: bool = False,
     ):
         """
-        Set's the mouse position to a certain x y relitive to the
+        Set's the mouse position to a certain x y relative to the
         top left corner of the client
 
         Args:
             x: x to set
             y: y to set
             convert_from_client: If the position should be converted from client to screen
+            use_post: If PostMessage should be used instead of SendMessage
         """
+        if use_post:
+            send_method = user32.PostMessageW
+        else:
+            send_method = user32.SendMessageW
+
         if convert_from_client:
             point = ctypes.wintypes.tagPOINT(x, y)
 
@@ -186,9 +208,12 @@ class Client:
             x = point.x
             y = point.y
 
-        await self._memory.write_mouse_position(x, y)
+        res = await self._memory.write_mouse_position(x, y)
+        # position doesn't matter here; sending mouse move
+        # mouse move is here so that items are highlighted
+        send_method(self.window_handle, 0x200, 0, 0)
+        return res
 
-    # TODO: replace with set_xyz
     async def teleport(
         self, x: float = None, y: float = None, z: float = None, yaw: float = None
     ) -> bool:
@@ -207,10 +232,10 @@ class Client:
         Returns:
             True if telelporting succseeded, False otherwise
         """
-        res = await self._memory.set_xyz(x=x, y=y, z=z)
+        res = await self.set_xyz(x=x, y=y, z=z)
 
         if yaw is not None:
-            await self._memory.set_player_yaw(yaw)
+            res = res and await self.set_yaw(yaw)
 
         return res
 
@@ -226,6 +251,18 @@ class Client:
         """
         return await self._memory.read_xyz()
 
+    async def set_xyz(self, x: float, y: float, z: float):
+        """
+        Set the player xyz
+
+        Raises:
+            RuntimeError: player_struct hook not active
+
+        Returns:
+            XYZ namedtuple or None if hooked function hasn't run yet
+        """
+        return await self._memory.set_xyz(x=x, y=y, z=z)
+
     async def yaw(self) -> Optional[float]:
         """
         Player yaw
